package com.fr.plugin.widget;


import com.fr.form.ui.TextEditor;
import com.fr.general.ComparatorUtils;
import com.fr.json.JSONException;
import com.fr.json.JSONObject;
import com.fr.plugin.MyFunctionConstants;
import com.fr.script.Calculator;
import com.fr.stable.core.NodeVisitor;
import com.fr.stable.web.Repository;
import com.fr.stable.xml.XMLPrintWriter;
import com.fr.stable.xml.XMLableReader;

/*
继承自TextEditor 可以帮我们节省很多配置的开发工作
如果实在不知道控件类型可以直接继承 Widget
这些类都再 com.fr.form.ui包中
 */
public class ICEEditorWidget extends TextEditor {

    private String config1="this is test config";
    private String config2=null;
    private String config3=null;

    public String getConfig1() {
        return config1;
    }

    public void setConfig1(String config1) {
        this.config1 = config1;
    }

    public String getConfig2() {
        return config2;
    }

    public void setConfig2(String config2) {
        this.config2 = config2;
    }

    public String getConfig3() {
        return config3;
    }

    public void setConfig3(String config3) {
        this.config3 = config3;
    }

    /**
     * 控件的类型
     * 注意这个类型要和前端js注册的名称一致！！！
     * @return
     */
    @Override
    public String getXType() {
        return MyFunctionConstants.WIDGET_NAME;
    }

    /**
     * 返回控件的属性json,这个对应的就是前端控件widget.options属性的,
     * 这里可以获取参数，返回给前端js
     * @param repository
     * @param calculator
     * @param nodeVisitor
     * @return
     * @throws JSONException
     */
    @Override
    public JSONObject createJSONConfig(Repository repository, Calculator calculator, NodeVisitor nodeVisitor) throws JSONException {
        //这里先将父类的json拿到再添加我们自己的配置（我这里没有配置，就随便返回了一个配置）
        return super.createJSONConfig(repository, calculator, nodeVisitor).put("customTitle", config1).put("config2",config2).put("config3",config3);
    }

    /**
     * 保存时候将设置保存在模板里面。
     * @param xmLableReader
     */
    @Override
    public void readXML(XMLableReader xmLableReader) {
        super.readXML(xmLableReader);
        if (xmLableReader.isChildNode()) {
            String tagName = xmLableReader.getTagName();
            if (ComparatorUtils.equals(tagName, "config1")) {
                 this.config1= xmLableReader.getAttrAsString("config1","");
            }
            if (ComparatorUtils.equals(tagName, "config2")) {
                this.config2= xmLableReader.getAttrAsString("config2","");
            }
            if (ComparatorUtils.equals(tagName, "config1")) {
                this.config3= xmLableReader.getAttrAsString("config3","");
            }
        }
    }

    /**
     * 从模板里面读取对应的属性 cpt解析之后实际上还是xml所以这里就是将配置转成xml
     * @param xmlPrintWriter
     */
    @Override
    public void writeXML(XMLPrintWriter xmlPrintWriter) {
        super.writeXML(xmlPrintWriter);
        xmlPrintWriter.startTAG("config1").textNode(config1).end();
        xmlPrintWriter.startTAG("config2").textNode(config2).end();
        xmlPrintWriter.startTAG("config3").textNode(config3).end();
    }

    @Override
    public boolean isEditor() {
        return true;
    }
}
